@@ -11,18 +11,18 @@ from slai.exceptions import NoCredentialsFound
 
 def requires_slai_credentials(callback, *outer_args, **outer_kwargs):
     def wrapper(*args, **kwargs):
+        profile_name = outer_kwargs.get("profile", "default")
+        runtime = detect_runtime()
+
         try:
-            runtime = detect_runtime()
-            detect_credentials(
-                runtime=runtime, profile=outer_kwargs.get("profile", "default")
-            )
+            detect_credentials(runtime=runtime, profile_name=profile_name)
         except NoCredentialsFound:
             log.warn("No credentials detected.")
 
             try:
                 has_api_key = click.confirm("Do you have an api key?")
                 if has_api_key:
-                    get_credentials()
+                    get_credentials(profile_name=profile_name, runtime=runtime)
                 else:
                     log.action("Create one at slai.io, then re-run this command.")
                     click.launch("https://slai.io")
