@@ -1,10 +1,6 @@
 import click
 import sys
 
-# REMOVE THESE
-sys.path.append("../slai")
-sys.path.append("../../slai")
-
 from functools import update_wrapper
 from slai_cli.run import commands as run
 from slai_cli.create import commands as create
