@@ -6,6 +6,7 @@ from slai_cli.model.open import open_model
 from slai_cli.model.list import list_models
 from slai_cli.model.train import train_model
 from slai_cli.model.call import call_model
+from slai_cli.model.test import test_model
 from slai_cli.model.deploy import deploy_model
 from slai_cli.model.checkout import checkout_model_version
 from slai_cli.exceptions import ModelExistsException, InvalidApiKey
@@ -71,6 +72,13 @@ def call(model_name):
     call_model(model_name=model_name, input={})
 
 
+@model.command()
+@click.argument("model_name")
+def test(model_name):
+    """Test a model/handler locally before deploying."""
+    test_model(model_name=model_name, input={})
+
+
 @model.command()
 @click.argument("model_name")
 @click.option(
