@@ -146,9 +146,11 @@ def deploy_model(*, model_name, version):
     log.action("Deploying model to slai backend.")
 
     project_client = get_project_client(project_name=None)
-    project_name = project_client.get_project_name()
+    project = project_client.get_project()
+    project_name = project["name"]
+    project_id = project["id"]
 
-    docker_client = DockerClient(project_name)
+    docker_client = DockerClient(project_name=project_name, project_id=project_id)
     model_client = get_model_client(model_name=model_name, project_name=project_name)
 
     local_config_helper = LocalConfigHelper()
