@@ -48,7 +48,10 @@ def open_model(model_name, watch):
     local_config_helper.check_local_config()
 
     project_client = get_project_client(project_name=None)
-    project_name = project_client.get_project_name()
+    project = project_client.get_project()
+    project_name = project["name"]
+    project_id = project["id"]
+
     model_client = get_model_client(model_name=model_name, project_name=project_name)
 
     local_model_config = local_config_helper.get_local_model_config(
@@ -64,7 +67,7 @@ def open_model(model_name, watch):
             model_name=model_name,
         )
     else:
-        docker_client = DockerClient(project_name)
+        docker_client = DockerClient(project_name=project_name, project_id=project_id)
 
         try:
             server_started = docker_client.launch_local_notebook_server(
