@@ -67,8 +67,9 @@ def _socket_output_worker(s, output_queue, stop_event):
 
 
 class DockerClient:
-    def __init__(self, project_name):
+    def __init__(self, *, project_name, project_id):
         self.project_name = project_name
+        self.project_id = project_id
         self.client = docker.from_env()
         self.docker_api_client = docker.APIClient(
             base_url="unix://var/run/docker.sock"
@@ -79,7 +80,7 @@ class DockerClient:
     def _connect_to_container(self):
         self.project_container = None
         containers = self.client.containers.list(
-            filters={"name": f"slai-{self.project_name}-workspace"}
+            filters={"name": f"slai-{self.project_name}-{self.project_id}-workspace"}
         )
 
         if len(containers) == 1:
@@ -114,6 +115,19 @@ class DockerClient:
         )
         return exit_code
 
+    def test_model(self, *, model_name, model_version_id):
+        exit_code = self._run_interactive_command(
+            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/setup_test_environment.py {model_name} {model_version_id}"  # noqa
+        )
+        if exit_code != 0:
+            return exit_code
+
+        exit_code = self._run_interactive_command(
+            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/test_model.py {model_name} {model_version_id}"  # noqa
+        )
+
+        return exit_code
+
     def install_requirement(self, *, model_name, requirement):
         exit_code = self._run_interactive_command(
             cmd=f"/workspace/env/{model_name}/bin/python -m pip install {requirement}"
@@ -121,7 +135,7 @@ class DockerClient:
         return exit_code
 
     def check_model_requirements(self, *, model_name, requirements):
-        log.action(f"Verifying artifact requirements...")
+        log.action("Verifying artifact requirements...")
         req_string = " ".join(
             [f"{req}{version}" for req, version in requirements.items()]
         )
