@@ -38,7 +38,7 @@ def store_credentials(*, profile_name, client_id, client_secret, runtime):
         "client_secret": client_secret,
     }
 
-    slai.login(client_id=client_id, client_secret=client_secret)
+    slai.login(client_id=client_id, client_secret=client_secret, key_type="USER")
 
     if runtime == ValidRuntimes.Local:
         credentials_path = f"{Path.home()}/.slai"
